
import sys
import string
from vh3 import virthost
from vh3.modules import diskquota
from vh3.modules import users
import vh3.modules.reseller as resellers
import configuration
import util
import cache

class AdminInformation:
    def __init__(self):
        self.fullname = None
        self.first_name = None
        self.last_name = None
        self.email = None
        self.id = None
        self.children = []

def get_site_admin(id):
    siteinfo = virthost.read_conf_file(id, 'siteinfo')[0]
    admin = cache.get_site_admin(siteinfo['admin'])
    if admin != None:
        return admin
    username = siteinfo['admin_user'] 
    domain   = siteinfo['domain'] 
    user = users.find_user(id, username)[0]
    admin = AdminInformation()
    fullname = user['fullname']
    admin.fullname = fullname
    admin.first_name, admin.last_name = util.get_name_parts(fullname)
    admin.email = "%s@%s" % (username, domain)
    admin.username = username
    admin.id = siteinfo['admin']
    return admin

def get_reseller(id):

    myid = int(id)

    reseller = cache.get_reseller(id)

    if reseller != None:
        return reseller

    reseller = resellers.get_reseller_with_id(myid)[0]

    admin = AdminInformation()
    admin.id = id
    fullname = reseller['fullname']
    admin.fullname = fullname
    admin.first_name, admin.last_name = util.get_name_parts(fullname)
    admin.email = reseller['email']
    admin.username = reseller['username']
    return admin

def save_reseller(quota):
    id = quota.admin_id
    reseller = cache.get_reseller(id)

    if reseller == None:
        reseller = get_reseller(id)

    reseller.children.append(quota.domain)
    cache.save_reseller(reseller)

def save_site_admin_by_id(id):
    admin = cache.get_site_admin(id)
    if admin == None:
        admin = get_site_admin(id)
    cache.save_site_admin(admin)
    return admin

def save_site_admin(quota):
    id = quota.admin_id
    admin = save_site_admin_by_id(id)
    admin.children.append(quota.username)
    cache.save_site_admin(admin)

def get_over_quota_resellers():
    values = []
    for r in cache.get_resellers().values():
        if len(r.children) > 0:
            values.append(r)
    return values

def get_over_quota_site_admins():
    values = []
    for a in cache.get_admins().values():
        if len(a.children) > 0:
            values.append(a)
    return values

def setup_global_reseller():
    c = configuration.get_configuration()
    admin = AdminInformation()
    admin.email = c.from_address
    admin.fullname = c.from_name
    admin.first_name, admin.last_name = util.get_name_parts(c.from_name)
    admin.id = '0'
    cache.save_reseller(admin)

setup_global_reseller()
