
import string
from vh3 import virthost
from vh3.modules import diskquota
from vh3.modules import users
import vh3.modules.reseller as reseller
import util

class QuotaInformation:
    def __init(self):
        self.total = 0L
        self.used = 0L
        self.free = 0L
        self.total_mb = 0.00
        self.used_mb = 0.00
        self.free_mb = 0.00
        self.percent_used = 0.00
        self.percent_free = 0.00
        self.email = ""
        self.domain = ""
        self.username = ""
        self.fullname = ""
        self.first_name = ""
        self.last_name = ""
        self.admin_id = 0
        self.id = 0

def get_all_site_ids():
    return virthost.get_domain_list()

def get_site_quota(index):

    if index == None:
        return None

    quota = diskquota.get_site_quota(index)

    if quota == None:
        return None

    total = quota[0]

    if total <= 0:
        return None

    site = virthost.get_configs_from_site(index)[0]

    used = diskquota.get_site_used_quota(index)[0]
    free = total - used
    percent_used = (float(used) / float(total)) * 100

    quota_info = QuotaInformation()
    quota_info.id = index
    quota_info.total = total
    quota_info.used = used
    quota_info.free = free
    quota_info.used_mb = "%.2f" % (used / (1024.00* 1024.00))
    quota_info.total_mb = "%.2f" %  (total / (1024.00 * 1024.00))
    quota_info.free_mb = "%.2f" %  (free / (1024.00 * 1024.00))
    quota_info.percent_used = int(percent_used)
    quota_info.percent_free = int(100.00 - percent_used)
    quota_info.email = site['siteinfo']['email']
    quota_info.domain = site['siteinfo']['domain']
    quota_info.admin_id = site['reseller']['reseller_id']

    return quota_info

def get_user_quotas(site_index):

    userlist = []

    siteinfo = virthost.read_conf_file(site_index, 'siteinfo')[0]
    domain = siteinfo['domain']
    admin_id = site_index
    domain_id = 0

    for name in users.get_usernames(site_index):
        user = users.find_user(site_index, name)[0]
        if user != None:
            if user['diskquota'] > 0:
                quota = QuotaInformation()
                total = user['diskquota']
                used  = user['used']
                free  = total - used
                percent_used = (float(used) / float(total)) * 100
                quota.id = user['username']
                quota.total = total
                quota.used  = used
                quota.free  = free
                quota.used_mb = "%.2f" % (used / (1024.00* 1024.00))
                quota.total_mb = "%.2f" %  (total / (1024.00 * 1024.00))
                quota.free_mb = "%.2f" %  (free / (1024.00 * 1024.00))
                quota.percent_used = int(percent_used)
                quota.percent_free = int(100.00 - percent_used)
                quota.email = "%s@%s" % (user['username'], domain)
                quota.domain = domain
                quota.admin_id = admin_id
                quota.username = user['username']
                quota.fullname = user['fullname']
                names = util.get_name_parts(user['fullname'])
                quota.first_name = names[0]
                quota.last_name = names[1]
                userlist.append(quota)

    return userlist

